@@ -156,7 +156,7 @@ where
         self.rows
             .next()
             .transpose()
-            .map(|row_result| row_result.and_then(|row| (map)(row)))
+            .map(|row_result| row_result.and_then(map))
     }
 }
 
@@ -181,7 +181,7 @@ where
         self.rows
             .next()
             .transpose()
-            .map(|row_result| row_result.map_err(E::from).and_then(|row| (map)(row)))
+            .map(|row_result| row_result.map_err(E::from).and_then(map))
     }
 }
 
